@@ -1,7 +1,7 @@
 #!/bin/bash
 # Install mecab, then build wheels
 set -e
-manylinux_version=1
+manylinux_version=2014
 plat=x86_64
 
 # install MeCab
@@ -25,7 +25,7 @@ make install
 export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/usr/local/lib/
 
 # Build the wheels
-for PYVER in cp36-cp36m cp37-cp37m cp38-cp38 cp39-cp39; do
+for PYVER in cp36-cp36m cp37-cp37m cp38-cp38 cp39-cp39 cp310-cp310; do
   # build the wheels
   /opt/python/$PYVER/bin/pip wheel /github/workspace -w /github/workspace/wheels || { echo "Failed while buiding $PYVER wheel"; exit 1; }
 done
